==> pretty-components-1.0.1.tgz: package/src/injector.js <==
let globalWindow;

if (!('window' in this)) {
  const jsdom = require('jsdom');
  globalWindow = new jsdom.JSDOM().window;
}

class Injector {
  constructor() {
    this.pendingStylesheets = [];
    this.renderedStylesheets = [];
    this.stylesDOMContainer = this.generateStylesDOMContainer();
  }

  /**
   * Register a given stylesheet and call for rendering.
   *
   * @param {Stylesheet} stylesheet
   */
  static registerStylesheet(stylesheet) {
    Injector._instance.pendingStylesheets.push(stylesheet);
    Injector._instance.renderStyles();
  }

  /**
   * Generate a <style> tag and append it to the current document's <head>.
   * This container will be used to inject all generated styles.
   */
  generateStylesDOMContainer() {
    const styleBlock = globalWindow.document.createElement('style');
    styleBlock.type = 'text/css';
    styleBlock.id = 'pretty';
    globalWindow.document.head.appendChild(styleBlock);
    return styleBlock;
  }

  /**
   * Render a given stylesheet.
   *
   * @param {Stylesheet} stylesheet
   */
  renderStylesheet(stylesheet) {
    if (!this.renderedStylesheets.includes(stylesheet.identifier)) {
      this.stylesDOMContainer.innerHTML += stylesheet.toCSS();
      this.renderedStylesheets.push(stylesheet.identifier);
    }
  }

  /**
   * Will render stylesheets pending to be rendered.
   */
  renderStyles() {
    for (const stylesheet of this.pendingStylesheets) {
      this.renderStylesheet(stylesheet);
    }

    for (let index = 0; index < this.pendingStylesheets.length; index++) {
      this.pendingStylesheets.splice(index, 1);
    }
  }
}

Injector._instance = new Injector();

module.exports = Injector;

==> pretty-components-1.0.3.tgz: package/src/injector.js <==
class Injector {
  constructor() {
    this.pendingStylesheets = [];
    this.renderedStylesheets = [];
    this.stylesDOMContainer = this.generateStylesDOMContainer();
  }

  /**
   * Register a given stylesheet and call for rendering.
   *
   * @param {Stylesheet} stylesheet
   */
  static registerStylesheet(stylesheet) {
    Injector._instance.pendingStylesheets.push(stylesheet);
    Injector._instance.renderStyles();
  }

  /**
   * Generate a <style> tag and append it to the current document's <head>.
   * This container will be used to inject all generated styles.
   */
  generateStylesDOMContainer() {
    const styleBlock = window.document.createElement('style');
    styleBlock.type = 'text/css';
    styleBlock.id = 'pretty';
    window.document.head.appendChild(styleBlock);
    return styleBlock;
  }

  /**
   * Render a given stylesheet.
   *
   * @param {Stylesheet} stylesheet
   */
  renderStylesheet(stylesheet) {
    if (!this.renderedStylesheets.includes(stylesheet.identifier)) {
      this.stylesDOMContainer.innerHTML += stylesheet.toCSS();
      this.renderedStylesheets.push(stylesheet.identifier);
    }
  }

  /**
   * Will render stylesheets pending to be rendered.
   */
  renderStyles() {
    for (const stylesheet of this.pendingStylesheets) {
      this.renderStylesheet(stylesheet);
    }

    for (let index = 0; index < this.pendingStylesheets.length; index++) {
      this.pendingStylesheets.splice(index, 1);
    }
  }
}

Injector._instance = new Injector();

module.exports = Injector;
